var CCMDB = WSUtil.extend({

  IBM_SOAP_VERSION: "1_2",
  
  CONTENT_TYPE: "application/soap+xml;charset=UTF-8;action=\"urn:processDocument\"",

  TIVOLI_WSDL_DEFN: "integrationservices/tivoli-ccmdb/soap/IBM-Tivoli-soapui-project.xml",
  MX: "http://www.ibm.com/maximo",

  init: function(endPoint, login, password)
  {
    this._super();
    this.endPoint = endPoint;
    this.authorization = this.base64Encode(login + ":" + password);
    
    // Set the request properties
    this.requestProperties = new HashMap();
    this.requestProperties.put("Authorization", "Basic " + this.authorization);
    this.requestProperties.put("Content-Type", this.CONTENT_TYPE);
  },
  
  /**
   * Retrieve the change for the current assignment
   * @param ownerid owner id of the assignment record
   * @return WOCHANGE object for the assignment
   */
  queryChangeAssignment: function(ownerid)
  {
    var msg = new SOAPMessage(this.TIVOLI_WSDL_DEFN, "QueryXMCHANGE", "QueryXMCHANGE", this.IBM_SOAP_VERSION);
  
    // Set the parameter values
    msg.setParameter("WORKORDERID", ownerid);
  
    // Post the message to the SOAP endpoint
    return this.sendReceive(this.endPoint, msg, this.requestProperties);
  },
  
  /**
   * Retrieve the task information for the current workflow assignment
   * @param app name of the application the workflow belongs to
   * @param nodeId id of the node in the workflow
   * @param processName name of the process within the workflow
   * @param processRev current revision of the workflow process
   * @return WFTASK object for the assignment
   */
  queryWorkflowTask: function(app, nodeId, processName, processRev)
  {
    var msg = new SOAPMessage(this.TIVOLI_WSDL_DEFN, "QueryXMTASK", "QueryXMTASK", this.IBM_SOAP_VERSION);
    
    // Set the parameter values
    msg.setParameter("APP", app);
    msg.setParameter("NODEID", nodeId);
    msg.setParameter("PROCESSNAME", processName);
    msg.setParameter("PROCESSREV", processRev);
  
    // Post the message to the SOAP endpoint
    return this.sendReceive(this.endPoint, msg, this.requestProperties);
  },

  /**
   * Enhance the APXML with the Change information for the current assignment
   * @param apxml APXML object to enhance
   * @param response XML Response containing the Change
   * @return enriched APXML
   */
  enrichAPXMLForChangeAssignment: function(apxml, response)
  {
    default xml namespace = this.MX;

    apxml.setToken("ch_wonum", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.WONUM, APXMLToken.Type.STRING);
    apxml.setToken("ch_owner", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.OWNER, APXMLToken.Type.STRING);
    apxml.setToken("ch_ownergroup", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.OWNERGROUP, APXMLToken.Type.STRING);
    apxml.setToken("ch_status", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.STATUS, APXMLToken.Type.STRING);
    apxml.setToken("ch_reportedby", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.REPORTEDBY, APXMLToken.Type.STRING);
    apxml.setToken("ch_description", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.DESCRIPTION, APXMLToken.Type.STRING);
    apxml.setToken("ch_changetype", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.PMCHGTYPE, APXMLToken.Type.STRING);
    apxml.setToken("ch_reasonforchange", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.REASONFORCHANGE, APXMLToken.Type.STRING);
    apxml.setToken("ch_effectofnotimplementing", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.PMCHGCONCERN, APXMLToken.Type.STRING);
    apxml.setToken("ch_affected_ci", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.CINUM, APXMLToken.Type.STRING);
    apxml.setToken("ch_affected_ci_name", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.CI.CINAME, APXMLToken.Type.STRING);
    apxml.setToken("ch_affected_ci_description", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.CI.DESCRIPTION, APXMLToken.Type.STRING);
    apxml.setToken("ch_site", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.SITEID, APXMLToken.Type.STRING);
    apxml.setToken("ch_risk", this.mapTivoliCodes("risk", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.RISK), APXMLToken.Type.STRING);
    apxml.setToken("ch_failureprobability", this.mapTivoliCodes("failureprobability", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.PMCHGPROBABILITYFAILURE), APXMLToken.Type.STRING);
    apxml.setToken("ch_impact", this.mapTivoliCodes("impact", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.PMCOMIMPACT), APXMLToken.Type.STRING);
    apxml.setToken("ch_urgency", this.mapTivoliCodes("urgency", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.PMCOMURGENCY), APXMLToken.Type.STRING);
    apxml.setToken("ch_priority", this.mapTivoliCodes("priority", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.WOPRIORITY), APXMLToken.Type.STRING);
    apxml.setToken("ch_changecategory", response.QueryXMCHANGEResponse.XMCHANGESet.WOCHANGE.PMCHGCAT, APXMLToken.Type.STRING);
    return apxml;
  },
  
  /**
   * Map the Tivoli codes to a meaningful value
   * @param code name of the code the map
   * @param value the value to translate
   * @return a mapped value
   */
  mapTivoliCodes: function(code, value)
  {
    if (value == 1)
    {
      if ("priority".equalsIgnoreCase(code))
      {
        return "Immediate";
      }
      if ("failureprobability".equalsIgnoreCase(code))
      {
        return "High";
      }
      return "Critical";
    }
    if (value == 2)
    {
      if ("failureprobability".equalsIgnoreCase(code))
      {
        return "Medium";
      }
      return "High";
    }

    if (value == 3)
    {
      if ("failureprobability".equalsIgnoreCase(code))
      {
        return "Low";
      }
      return "Medium";
    }

    if (value == 4)
    {
      return "Low";
    }

    if (value == 5)
    {
      if ("risk".equalsIgnoreCase(code))
      {
        return "None";
      }
      return "Planning";
    }
    return value;
  },
  
  /**
   * Enhance the APXML with the Change information for the current assignment
   * @param apxml APXML object to enhance
   * @param response XML Response containing the Change
   * @return enriched APXML
   */
  enrichAPXMLForWFTask: function(apxml, response)
  {
    default xml namespace = this.MX;
    // incident_id is a special token and should not be prefixed with ch_ even though the value is the change id
    apxml.setToken("wf_firstcomplete", response.QueryXMTASKResponse.XMTASKSet.WFTASK.FIRSTCOMPLETE, APXMLToken.Type.STRING);
    return apxml;
  },
  
  /**
   * Send the request to update the workflow
   * @param app type of application the workflow applies to
   * @param assignId id of the workflow assignment
   * @param nodeId id of the workflow node the assignment relates to
   * @param processName name of the process in the workflow that is being completed
   * @param processRev revision of the workflow process
   * @param wfAssignmentId unique id of the workflow assignment
   * @param wfId id of the workflow task
   * @param actionId id of the action to perform
   * @param memo note to add to the complete request
   */
  sendCompleteAssignmentRequest: function(app, assignId, nodeId, processName, processRev, wfAssignmentId, wfId, actionId, memo)
  {
    var msg = new SOAPMessage(this.TIVOLI_WSDL_DEFN, "UpdateXMASSIGNMENT", "CompleteXMASSIGNMENT", this.IBM_SOAP_VERSION);
    
    // Set the parameter values
    msg.setParameter("APP", app);
    msg.setParameter("ASSIGNID", assignId);
    msg.setParameter("NODEID", nodeId);
    msg.setParameter("PROCESSNAME", processName);
    msg.setParameter("PROCESSREV", processRev);
    msg.setParameter("WFASSIGNMENTID", wfAssignmentId);
    msg.setParameter("WFID", wfId);
    msg.setParameter("ACTIONID", actionId);
    msg.setParameter("MEMO", memo);
  
    // Post the message to the SOAP endpoint
    return this.sendReceive(this.endPoint, msg, this.requestProperties);
  },

  /**
   * Send the request to reassign the workflow
   * @param app type of application the workflow applies to
   * @param assignId id of the workflow assignment
   * @param nodeId id of the workflow node the assignment relates to
   * @param processName name of the process in the workflow that is being completed
   * @param processRev revision of the workflow process
   * @param wfAssignmentId unique id of the workflow assignment
   * @param wfId id of the workflow task
   * @param assignee name of the user to assign the workflow to
   * @param memo note to add to the reassignment request
   * @param sendEmail indicator to determine whether to notify the user
   * @param taskDesc update description for the reassignment task
   */
  sendReassignRequest: function(app, assignId, nodeId, processName, processRev, wfAssignmentId, wfId, assignee, memo, sendEmail, taskDesc)
  {
    var msg = new SOAPMessage(this.TIVOLI_WSDL_DEFN, "UpdateXMASSIGNMENT", "ReassignXMASSIGNMENT", this.IBM_SOAP_VERSION);
    
    // Set the parameter values
    msg.setParameter("APP", app);
    msg.setParameter("ASSIGNID", assignId);
    msg.setParameter("NODEID", nodeId);
    msg.setParameter("PROCESSNAME", processName);
    msg.setParameter("PROCESSREV", processRev);
    msg.setParameter("WFASSIGNMENTID", wfAssignmentId);
    msg.setParameter("WFID", wfId);
    msg.setParameter("ASSIGNEE", assignee);
    msg.setParameter("MEMO", memo);
    msg.setParameter("SENDEMAIL", sendEmail);
    msg.setParameter("TASKDESC", taskDesc);
  
    // Post the message to the SOAP endpoint
    return this.sendReceive(this.endPoint, msg, this.requestProperties);
  },
  
  /**
   * Send the request to add to the WorkLog
   * @param siteId id of the site the change refers to
   * @param workOrderId id of the workorder
   * @param wonum change number
   * @param clientViewable 0 for false, 1 for true
   * @param description log message
   * @param logType CLIENTNOTE, UPDATE or WORK
   */
  sendAnnotateRequest: function(siteId, workOrderId, wonum, clientViewable, description, logType)
  {
    var msg = new SOAPMessage(this.TIVOLI_WSDL_DEFN, "UpdateXMCHANGE", "UpdateXMCHANGEWorklog", this.IBM_SOAP_VERSION);

    msg.setParameter("SITEID", siteId);
    msg.setParameter("WORKORDERID", workOrderId);
    msg.setParameter("WONUM", wonum);
    msg.setParameter("CLIENTVIEWABLE", clientViewable);
    msg.setParameter("DESCRIPTION", description);
    msg.setParameter("LOGTYPE", logType);
    msg.setParameter("RECORDKEY", wonum);

    // Post the message to the SOAP endpoint
    return this.sendReceive(this.endPoint, msg, this.requestProperties);
  },
  
  /**
   * Query the Tivoli System for Configuration Items
   * @param whereClause String containing the filter criteria
   * @return collection of matching configuration items
   */
  queryConfigurationItems: function(whereClause)
  {
    var msg = new SOAPMessage(this.TIVOLI_WSDL_DEFN, "QueryXMCI", "QueryXMCI", this.IBM_SOAP_VERSION);

    msg.setParameter("WHERE", whereClause);

    // Post the message to the SOAP endpoint
    return this.sendReceive(this.endPoint, msg, this.requestProperties);
  }
 
});

