<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:mx="http://www.ibm.com/maximo"
  xmlns:util="xalan://com.xmatters.ibm.tivoli.util.SyncUtil"
  extension-element-prefixes="util">
  <xsl:output method="xml" />

  <!-- 
    Define the rules dictating if this incident is suppressed or not.
    In order to have the event injected into AlarmPoint there must
    be content generated from this xsl document containing the XML
    request that will be sent to the Integration Agent
   -->
  <xsl:template match="//mx:WOCHANGE">
    <xsl:apply-templates select="../mx:WOCHANGE" mode="process"/>
  </xsl:template>
  
  <!--
    Create the content to be sent to the Integration Agent 
   -->
  <xsl:template match="mx:WOCHANGE" mode="process">
    <!-- Default Integration Agent XML -->
    <transaction>
      <header>
        <method>
          Add
        </method>
        <subclass>
          Action
        </subclass>
      </header>
      <data>
        <publishchannel>XMCHANGE</publishchannel>
        <!-- Add injected event parameters -->
        <action_script_set>tivoli-ccmdb</action_script_set>
        <agent_client_id>tivoli-ccmdb</agent_client_id>
        <incident_id><xsl:value-of select="mx:WONUM"/></incident_id>
        <ch_wonum><xsl:value-of select="mx:WONUM"/></ch_wonum>
        <ch_site><xsl:value-of select="mx:SITEID"/></ch_site>
        <ch_ownerid><xsl:value-of select="mx:WORKORDERID"/></ch_ownerid>
        <owner><xsl:value-of select="mx:OWNER"/></owner>
        <ownergroup><xsl:value-of select="mx:OWNERGROUP"/></ownergroup>
        <status><xsl:value-of select="mx:STATUS"/></status>
        <reportedby><xsl:value-of select="mx:REPORTEDBY"/></reportedby>
        <summary><xsl:value-of select="mx:DESCRIPTION"/></summary>
        <changetype><xsl:value-of select="mx:PMCHGTYPE"/></changetype>
        <reasonforchange><xsl:value-of select="mx:REASONFORCHANGE"/></reasonforchange>
        <effectofnotimplementing><xsl:value-of select="mx:PMCHGCONCERN"/></effectofnotimplementing>
        <affected_ci><xsl:value-of select="mx:CINUM"/></affected_ci>
        <affected_ci_name><xsl:value-of select="mx:CI/mx:CINAME"/></affected_ci_name>
        <affected_ci_description><xsl:value-of select="mx:CI/mx:DESCRIPTION"/></affected_ci_description>        
        <site><xsl:value-of select="mx:SITEID"/></site>
        <risk>
          <xsl:choose>
            <xsl:when test="mx:RISK = '1'">Critical</xsl:when>
            <xsl:when test="mx:RISK = '2'">High</xsl:when>
            <xsl:when test="mx:RISK = '3'">Medium</xsl:when>
            <xsl:when test="mx:RISK = '4'">Low</xsl:when>
            <xsl:when test="mx:RISK = '5'">None</xsl:when>
          </xsl:choose>
        </risk>
        <failureprobability>
          <xsl:choose>
            <xsl:when test="mx:PMCHGPROBABILITYFAILURE = '1'">High</xsl:when>
            <xsl:when test="mx:PMCHGPROBABILITYFAILURE = '2'">Medium</xsl:when>
            <xsl:when test="mx:PMCHGPROBABILITYFAILURE = '3'">Low</xsl:when>
          </xsl:choose>
        </failureprobability>
        <impact>
          <xsl:choose>
            <xsl:when test="mx:PMCOMIMPACT = '1'">Critical</xsl:when>
            <xsl:when test="mx:PMCOMIMPACT = '2'">High</xsl:when>
            <xsl:when test="mx:PMCOMIMPACT = '3'">Medium</xsl:when>
            <xsl:when test="mx:PMCOMIMPACT = '4'">Low</xsl:when>
            <xsl:when test="mx:PMCOMIMPACT = '5'">Planning</xsl:when>
          </xsl:choose>
        </impact>
        <urgency>
          <xsl:choose>
            <xsl:when test="mx:PMCOMURGENCY = '1'">Critical</xsl:when>
            <xsl:when test="mx:PMCOMURGENCY = '2'">High</xsl:when>
            <xsl:when test="mx:PMCOMURGENCY = '3'">Medium</xsl:when>
            <xsl:when test="mx:PMCOMURGENCY = '4'">Low</xsl:when>
            <xsl:when test="mx:PMCOMURGENCY = '5'">Planning</xsl:when>
          </xsl:choose>
        </urgency>
        <priority>
          <xsl:choose>
            <xsl:when test="mx:WOPRIORITY = '1'">Immediate</xsl:when>
            <xsl:when test="mx:WOPRIORITY = '2'">High</xsl:when>
            <xsl:when test="mx:WOPRIORITY = '3'">Medium</xsl:when>
            <xsl:when test="mx:WOPRIORITY = '4'">Low</xsl:when>
            <xsl:when test="mx:WOPRIORITY = '5'">Planning</xsl:when>
          </xsl:choose>
        </priority>
        <changecategory><xsl:value-of select="mx:PMCHGCAT"/></changecategory>
        <xsl:for-each select="mx:PMCHGSCHEDAPPROVERS">
          <xsl:element name="scheduledapprovernode()">
            <xsl:if test="mx:APPROVER != ''">
              <xsl:value-of select="mx:APPROVER"/>
              <xsl:text>,</xsl:text>
            </xsl:if>
            <xsl:if test="mx:OWNERGROUP != ''">
              <xsl:value-of select="mx:OWNERGROUP"/>
            </xsl:if>
          </xsl:element>
        </xsl:for-each>
        <xsl:for-each select="mx:PMCHGOTHERAPPROVERS">
          <xsl:element name="otherapprovernode()">
            <xsl:if test="mx:APPROVER != ''">
              <xsl:value-of select="mx:APPROVER"/>
              <xsl:text>,</xsl:text>
            </xsl:if>
            <xsl:if test="mx:OWNERGROUP != ''">
              <xsl:value-of select="mx:OWNERGROUP"/>
            </xsl:if>
          </xsl:element>
        </xsl:for-each>
        <fyi>yes</fyi>
        <!-- Create a new event token for each element with data in the incident XML -->
        <!-- Uncomment the following to inject all incident information available -->
        <!--xsl:apply-templates select="node()" mode="tokens" /-->
      </data>
    </transaction>
  </xsl:template>

  <!--
    Create a new event token for each element at the current parsing level that contains text
   -->
  <xsl:template match="node()" mode="tokens">
    <xsl:if test="normalize-space(text()) != ''">
      <xsl:element name="{name()}">
        <xsl:attribute name="type">string</xsl:attribute>
        <xsl:value-of select="text()" />
      </xsl:element>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>