<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:mx="http://www.ibm.com/maximo"
  xmlns:ap="http://www.alarmpoint.com/webservices/schema"
  xmlns:util="xalan://com.xmatters.ibm.tivoli.util.SyncUtil"
  extension-element-prefixes="util"
  xmlns:xalan="http://xml.apache.org/xalan"
  exclude-result-prefixes="xalan">
  <xsl:output method="xml" />

  <xsl:variable name="id" select="//mx:PERSONGROUP/mx:PERSONGROUP/text()"/>
  <xsl:variable name="apostrophe" select='"&apos;"'/>

  <xsl:include href="GroupSyncRules.xsl"/>
  
  <!-- Include ONLY those objects which are on the groupList -->
  <xsl:template match="//mx:PERSONGROUP[$groupAction = 'INCLUDE']" priority="1">
    <xsl:choose>
      <xsl:when test="xalan:nodeset($groupList)/group/mx:PERSONGROUP[text() = $id]">
        <xsl:apply-templates select="../mx:PERSONGROUP" mode="process" />
      </xsl:when>
      <xsl:otherwise>
        <suppressionMessage>Do not sync coverage <xsl:value-of select="mx:PERSONGROUP"/>: the groupAction is set to INCLUDE, but the PERSONGROUP is not in the specified groupList.</suppressionMessage>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Exclude those objects which are on the groupList -->
  <xsl:template match="//mx:PERSONGROUP[$groupAction = 'EXCLUDE']" priority="1">
    <xsl:choose>
      <xsl:when test="xalan:nodeset($groupList)/group/mx:PERSONGROUP[text() = $id]">
        <suppressionMessage>Do not sync coverage <xsl:value-of select="mx:PERSONGROUP"/>: the groupAction is set to EXCLUDE and the PERSONGROUP is in the groupList to be excluded.</suppressionMessage>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="../mx:PERSONGROUP" mode="process" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Include all objects by default if a groupAction is not set -->
  <xsl:template match="//mx:PERSONGROUP" priority="0">
    <xsl:apply-templates select="../mx:PERSONGROUP" mode="process" />
  </xsl:template>

  <!-- 
    Parse out the AlarmPoint coverage information from the Maximo PERSONGROUP
   -->
  <xsl:template match="mx:PERSONGROUP" mode="process">
    <ap:coverage xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
      <!-- The group attribute is required and must be the name of the group this coverage is for -->
      <xsl:attribute name="group">
        <xsl:value-of select="mx:PERSONGROUP" />
      </xsl:attribute>
    
      <!-- Define the default behavior here -->
      <xsl:attribute name="seedOnly">false</xsl:attribute>
      <!-- Override the default behavior if necessary -->
      <xsl:if test="xalan:nodeset($seedOnlyList)/group/mx:PERSONGROUP[text() = $id]">
        <xsl:attribute name="seedOnly">true</xsl:attribute>
      </xsl:if>
      
      <ap:holidayShift xsi:nil="true" />
      <ap:name><xsl:value-of select="translate(mx:PERSONGROUP, $apostrophe, '')"/>_24x7</ap:name>
      <ap:oneTimeShift xsi:nil="true" />
      <ap:recurringShift>
        <ap:dayList>
          <ap:friday>true</ap:friday>
          <ap:monday>true</ap:monday>
          <ap:saturday>true</ap:saturday>
          <ap:sunday>true</ap:sunday>
          <ap:thursday>true</ap:thursday>
          <ap:tuesday>true</ap:tuesday>
          <ap:wednesday>true</ap:wednesday>
        </ap:dayList>
        <ap:durationHours>24</ap:durationHours>
        <ap:durationMinutes>0</ap:durationMinutes>
        <ap:excludeHolidays>true</ap:excludeHolidays>
        <ap:includeHolidays>false</ap:includeHolidays>
        <ap:recurrence>
          <ap:endDate></ap:endDate>
          <ap:frequency>WEEKLY</ap:frequency>
          <ap:interval>1</ap:interval>
          <ap:noEndDate>true</ap:noEndDate>
          <ap:occurrences></ap:occurrences>
          <ap:startDate>01/01/2005</ap:startDate>
        </ap:recurrence>
        <ap:startTime>00:00</ap:startTime>
      </ap:recurringShift>
      <ap:teamName><xsl:value-of select="translate(mx:PERSONGROUP, $apostrophe, '')"/>-Team</ap:teamName>
    </ap:coverage>
  </xsl:template>
</xsl:stylesheet>
