<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:mx="http://www.ibm.com/maximo"
  xmlns:util="xalan://com.xmatters.ibm.tivoli.util.SyncUtil"
  extension-element-prefixes="util">
  <xsl:output method="xml" />

  <!-- 
    Define the rules dictating if this incident is suppressed or not.
    In order to have the event injected into AlarmPoint there must
    be content generated from this xsl document containing the XML
    request that will be sent to the Integration Agent
   -->
  <xsl:template match="//mx:INCIDENT">
    <xsl:choose>
      <xsl:when test="mx:TICKETID = ''">
        <suppressionMessage>No Ticket ID</suppressionMessage>
      </xsl:when>
      <xsl:when test="mx:REPORTEDPRIORITY = ''">
        <suppressionMessage>No Reported Priority</suppressionMessage>
      </xsl:when>
      <xsl:when test="mx:STATUS = ''">
        <suppressionMessage>No Status</suppressionMessage>
      </xsl:when>
      <xsl:when test="mx:STATUS = 'CLOSED'">
        <suppressionMessage>Incident is CLOSED</suppressionMessage>
      </xsl:when>
      <xsl:when test="mx:REPORTEDPRIORITY &gt; 2">
        <suppressionMessage>Priority of <xsl:value-of select="mx:REPORTEDPRIORITY"/> is Suppressed</suppressionMessage>
      </xsl:when>
      <xsl:when test="@action = 'Replace' and not(mx:STATUS/@changed) and not(mx:REPORTEDPRIORITY/@changed) and not(mx:OWNER/@changed) and not(mx:OWNERGROUP/@changed)">
        <suppressionMessage>Replace Action With No Status, Priority or Ownership Updates</suppressionMessage>
      </xsl:when>
      <xsl:when test="not(@action = 'Add' or @action = 'Replace')">
        <suppressionMessage>Invalid Action: <xsl:value-of select="@action" /></suppressionMessage>
      </xsl:when>
      <xsl:otherwise>
        <!-- All suppression filters have passed so process the incident -->
        <xsl:apply-templates select="../mx:INCIDENT" mode="process"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!--
    Create the content to be sent to the Integration Agent 
   -->
  <xsl:template match="mx:INCIDENT" mode="process">
    <!-- Default Integration Agent XML -->
    <transaction>
      <header>
        <method>
          Add
        </method>
        <subclass>
          Action
        </subclass>
      </header>
      <data>
        <!-- Add injected event parameters -->
        <action_script_set>tivoli-srm</action_script_set>
        <agent_client_id>tivoli-srm</agent_client_id>
        <incident_id><xsl:value-of select="mx:TICKETID"/></incident_id>
        <!-- Specify that recipients are seperated by a ',' character -->
        <recipients-list-item-delimiter>,</recipients-list-item-delimiter>
        <!-- Select which recipients to notify -->
        <recipients>
          <xsl:choose>
            <!-- If only the status has changed, we want to send an FYI notification (i.e., no recipients) -->
            <xsl:when test="@action = 'Replace' and (mx:STATUS/@changed) and not(mx:REPORTEDPRIORITY/@changed) and not(mx:OWNER/@changed) and not(mx:OWNERGROUP/@changed)">
            </xsl:when>
            <!-- If the owner of the ticket didn't just change it notify them -->
            <xsl:when test="mx:OWNER != '' and not(mx:OWNER = mx:CHANGEBY)">
              <xsl:value-of select="mx:OWNER"/>
            </xsl:when>
            <!-- If we do not have a owner but have a owner group notify the group -->
            <xsl:when test="mx:OWNER = '' and mx:OWNERGROUP != ''">
              <xsl:value-of select="mx:OWNERGROUP"/>
            </xsl:when>
          </xsl:choose>
        </recipients>
        <owner><xsl:value-of select="mx:OWNER"/></owner>
        <ownergroup><xsl:value-of select="mx:OWNERGROUP"/></ownergroup>
        <classification><xsl:value-of select="mx:CLASSIFICATIONID"/></classification>
        <reportedby><xsl:value-of select="mx:REPORTEDBY"/></reportedby>
        <affectedperson><xsl:value-of select="mx:AFFECTEDPERSON"/></affectedperson>
        <affectedphone><xsl:value-of select="mx:AFFECTEDPHONE"/></affectedphone>
        <asset><xsl:value-of select="mx:ASSETNUM"/></asset>
        <assetsite><xsl:value-of select="mx:ASSETSITEID"/></assetsite>
        <affected_ci><xsl:value-of select="mx:CINUM"/></affected_ci>
        <description><xsl:value-of select="mx:DESCRIPTION"/></description>
        <location><xsl:value-of select="mx:LOCATION"/></location>
        <reportedpriority>
          <xsl:choose>
            <xsl:when test="mx:REPORTEDPRIORITY = '1'">Urgent</xsl:when>
            <xsl:when test="mx:REPORTEDPRIORITY = '2'">High</xsl:when>
            <xsl:when test="mx:REPORTEDPRIORITY = '3'">Medium</xsl:when>
            <xsl:when test="mx:REPORTEDPRIORITY = '4'">Low</xsl:when>
          </xsl:choose>
        </reportedpriority>
        <commoditygroup><xsl:value-of select="mx:COMMODITYGROUP"/></commoditygroup>
        <commodity><xsl:value-of select="mx:COMMODITY"/></commodity>
        <classification><xsl:value-of select="mx:CLASSIFICATIONID"/></classification>
        <site><xsl:value-of select="mx:SITEID"/></site>
        <status><xsl:value-of select="mx:STATUS"/></status>
        <impact><xsl:value-of select="mx:IMPACT"/></impact>
        <urgency><xsl:value-of select="mx:URGENCY"/></urgency>
        <internalpriority>
          <xsl:choose>
            <xsl:when test="mx:INTERNALPRIORITY = '1'">Urgent</xsl:when>
            <xsl:when test="mx:INTERNALPRIORITY = '2'">High</xsl:when>
            <xsl:when test="mx:INTERNALPRIORITY = '3'">Medium</xsl:when>
            <xsl:when test="mx:INTERNALPRIORITY = '4'">Low</xsl:when>
          </xsl:choose>
        </internalpriority>
        <!-- If the status is RESOLVED create a FYI notification -->
        <xsl:if test="mx:STATUS = 'RESOLVED' or (@action = 'Replace' and (mx:STATUS/@changed) and not(mx:REPORTEDPRIORITY/@changed) and not(mx:OWNER/@changed) and not(mx:OWNERGROUP/@changed))">
          <fyi>yes</fyi>
        </xsl:if>
        <!-- Create a new event token for each element with data in the incident XML -->
        <!-- Uncomment the following to inject all incident information available -->
        <!--xsl:apply-templates select="node()" mode="tokens" /-->
      </data>
    </transaction>
  </xsl:template>

  <!--
    Create a new event token for each element at the current parsing level that contains text
   -->
  <xsl:template match="node()" mode="tokens">
    <xsl:if test="normalize-space(text()) != ''">
      <xsl:element name="{name()}">
        <xsl:attribute name="type">string</xsl:attribute>
        <xsl:value-of select="text()" />
      </xsl:element>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>
