<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:mx="http://www.ibm.com/maximo"
  xmlns:ap="http://www.alarmpoint.com/webservices/schema"
  xmlns:util="xalan://com.xmatters.ibm.tivoli.util.SyncUtil"
  extension-element-prefixes="util"
  xmlns:xalan="http://xml.apache.org/xalan"
  exclude-result-prefixes="xalan">
  <xsl:output method="xml" />

  <xsl:variable name="id" select="//mx:PERSON/mx:PERSONID/text()"/>
  
  <xsl:include href="PersonSyncRules.xsl"/>
  
  <!-- Include all objects by default if a personAction is not set -->
  <xsl:template match="//mx:PERSON[mx:APSYNC[text() = '1']]" priority="1">
    <xsl:apply-templates select="../mx:PERSON" mode="apply-sync-rules"/>
  </xsl:template>

  <!-- Include all objects by default if a personAction is not set -->
  <xsl:template match="//mx:PERSON[mx:APSYNC[text() = '0']]" priority="1">
    <suppressionMessage>Do not sync person <xsl:value-of select="mx:PERSONID"/>: they are not marked as Synchronize with AlarmPoint within Tivoli SRM.</suppressionMessage>
  </xsl:template>

  <!-- Include all objects by default if a personAction is not set -->
  <xsl:template match="//mx:PERSON" priority="0">
    <xsl:apply-templates select="../mx:PERSON" mode="apply-sync-rules" />
  </xsl:template>

  <!-- Include ONLY those objects which are on the personList -->
  <xsl:template match="//mx:PERSON[$personAction = 'INCLUDE']" priority="1" mode="apply-sync-rules">
    <xsl:choose>
      <xsl:when test="xalan:nodeset($personList)/person/mx:PERSONID[text() = $id]">
        <xsl:apply-templates select="../mx:PERSON" mode="process" />
      </xsl:when>
      <xsl:otherwise>
        <suppressionMessage>Do not sync person <xsl:value-of select="mx:PERSONID"/>: the personAction is set to INCLUDE, but the PERSONID is not in the specified personList.</suppressionMessage>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Exclude those objects which are on the personList -->
  <xsl:template match="//mx:PERSON[$personAction = 'EXCLUDE']" priority="1" mode="apply-sync-rules">
    <xsl:choose>
      <xsl:when test="xalan:nodeset($personList)/person/mx:PERSONID[text() = $id]">
        <suppressionMessage>Do not sync person <xsl:value-of select="mx:PERSONID"/>: the personAction is set to EXCLUDE and the PERSONID is in the personList to be excluded.</suppressionMessage>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="../mx:PERSON" mode="process" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Include all objects by default if a personAction is not set -->
  <xsl:template match="//mx:PERSON" priority="0" mode="apply-sync-rules">
    <xsl:apply-templates select="../mx:PERSON" mode="process" />
  </xsl:template>

  <!-- 
    Parse out the AlarmPoint user information from the Maximo PERSON 
   -->
  <xsl:template match="mx:PERSON" mode="process">
    <ap:person>

      <!-- Define the default behavior here -->
      <xsl:attribute name="seedOnly">false</xsl:attribute>
      <!-- Override the default behavior if necessary -->
      <xsl:if test="xalan:nodeset($seedOnlyList)/person/mx:PERSONID[text() = $id]">
        <xsl:attribute name="seedOnly">true</xsl:attribute>
      </xsl:if>
      
      <!-- Define the default behavior here -->
      <xsl:attribute name="deletable">true</xsl:attribute>
      <!-- Override the default behavior if necessary -->
      <xsl:if test="xalan:nodeset($undeletableList)/person/mx:PERSONID[text() = $id]">
        <xsl:attribute name="deletable">false</xsl:attribute>
      </xsl:if>

      <ap:externallyOwned>false</ap:externallyOwned>
      
      <xsl:choose>
        <xsl:when test="mx:STATUS = 'ACTIVE'">
          <ap:active>true</ap:active>
        </xsl:when>
        <xsl:otherwise>
          <ap:active>false</ap:active>
        </xsl:otherwise>
      </xsl:choose>
      <ap:customAttributes>
        <!--ap:customAttribute>
          <ap:name>?</ap:name>
          <ap:value>?</ap:value>
        </ap:customAttribute-->
      </ap:customAttributes>
      <ap:customFields>
        <!--ap:customField>
          <ap:name>?</ap:name>
          <ap:value>?</ap:value>
        </ap:customField-->
      </ap:customFields>
      <xsl:choose>
        <xsl:when test="mx:FIRSTNAME != ''">
          <ap:firstName><xsl:value-of select="mx:FIRSTNAME"/></ap:firstName>
        </xsl:when>
        <xsl:otherwise>
          <ap:firstName>Tivoli SRM</ap:firstName>
        </xsl:otherwise>
      </xsl:choose>
      <ap:hasMobileAccess>false</ap:hasMobileAccess>

      <!-- Apply template for SRM abbreviated language -->
      <xsl:apply-templates select="mx:LANGUAGE" />

      <xsl:choose>
        <xsl:when test="mx:LASTNAME != ''">
      <ap:lastName><xsl:value-of select="mx:LASTNAME"/></ap:lastName>
        </xsl:when>
        <xsl:otherwise>
          <ap:lastName>User</ap:lastName>
        </xsl:otherwise>
      </xsl:choose>
      <ap:phoneLogin>
        <ap:hasPhoneLogin>false</ap:hasPhoneLogin>
        <ap:phoneLogin></ap:phoneLogin>
        <ap:phonePassword></ap:phonePassword>
      </ap:phoneLogin>
      <ap:roles>
        <ap:role>
          <ap:name>Standard User</ap:name>
        </ap:role>
      </ap:roles>
      <ap:site>Default Site</ap:site>
      <ap:supervisors>
        <ap:supervisor>
          <ap:targetName>tivoliadmin</ap:targetName>
        </ap:supervisor>
      </ap:supervisors>
      <ap:targetName><xsl:value-of select="mx:PERSONID"/></ap:targetName>

      <!-- Apply template for SRM timezone mapping -->
      <xsl:apply-templates select="mx:TIMEZONE" />

      <ap:webLogin>
        <ap:ldapDomain></ap:ldapDomain>
        <ap:login><xsl:value-of select="mx:PERSONID"/></ap:login>
        <ap:password>password</ap:password>
        <ap:type>NATIVE</ap:type>
      </ap:webLogin>
    </ap:person>
  </xsl:template>

  <!-- Process the 2 letter language abbreviation from SRM into the AlarmPoint equivalent -->
  <xsl:template match="mx:LANGUAGE">
    <xsl:choose>
      <xsl:when test="text() = 'EN'">
        <ap:language>English</ap:language>
      </xsl:when>
      <xsl:when test="text() = 'DE'">
        <ap:language>German</ap:language>
      </xsl:when>
      <xsl:when test="text() = 'ES'">
        <ap:language>Spanish</ap:language>
      </xsl:when>
      <xsl:when test="text() = 'FR'">
        <ap:language>French</ap:language>
      </xsl:when>
      <xsl:when test="text() = 'IT'">
        <ap:language>Italian</ap:language>
      </xsl:when>
      <xsl:when test="text() = 'JA'">
        <ap:language>Japanese</ap:language>
      </xsl:when>
      <xsl:when test="text() = 'KO'">
        <ap:language>Korean</ap:language>
      </xsl:when>
      <xsl:when test="text() = 'PT'">
        <ap:language>Portuguese</ap:language>
      </xsl:when>
      <xsl:when test="text() = 'RU'">
        <ap:language>Russian</ap:language>
      </xsl:when>
      <xsl:when test="text() = 'ZL'">
        <ap:language>Chinese</ap:language>
      </xsl:when>
      <xsl:when test="text() = 'ZH'">
        <ap:language>Chinese</ap:language>
      </xsl:when>
      <xsl:otherwise>
        <ap:language>English</ap:language>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Add appropriate mappings from the TSRM Timezones to the appropriate Timezone in xMatters. -->
  <xsl:template match="mx:TIMEZONE">
    <xsl:choose>
      <xsl:when test="text() = 'America/Caracas'">
        <ap:timeZone>Canada/Atlantic</ap:timeZone>
      </xsl:when>
      <!-- MODIFY THIS SECTION WITH CARE - THIS IS THE DEFAULT ACTION IF NO MATCH IS FOUND ABOVE.
           IF NO MATCH IS FOUND, IT WILL SEND THE SELECTED TEXT IN THE mx:TIMEZONE NODE UNLESS
           IT IS BLANK, IN WHICH CASE IT WILL SET THE TIMEZONE TO US/Pacific -->
      <xsl:otherwise>
        <xsl:choose>
          <xsl:when test="text() != ''">
            <ap:timeZone><xsl:value-of select="text()"/></ap:timeZone>
          </xsl:when>
          <xsl:otherwise>
            <ap:timeZone>US/Pacific</ap:timeZone>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
    

</xsl:stylesheet>
