<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:mx="http://www.ibm.com/maximo"
  xmlns:ap="http://www.alarmpoint.com/webservices/schema"
  xmlns:util="xalan://com.xmatters.ibm.tivoli.util.SyncUtil"
  extension-element-prefixes="util"
  xmlns:xalan="http://xml.apache.org/xalan"
  exclude-result-prefixes="xalan">
  <xsl:output method="xml" />

  <xsl:variable name="id" select="//mx:PERSON/mx:PERSONID/text()"/>

  <xsl:include href="PersonSyncRules.xsl"/>
  <xsl:include href="UserSMSDevice.xsl"/>

  <!-- Include all objects by default if a personAction is not set -->
  <xsl:template match="//mx:PERSON[mx:APSYNC[text() = '1']]" priority="1">
    <xsl:apply-templates select="../mx:PERSON" mode="apply-sync-rules"/>
  </xsl:template>

  <!-- Include all objects by default if a personAction is not set -->
  <xsl:template match="//mx:PERSON[mx:APSYNC[text() = '0']]" priority="1">
    <suppressionMessage>Do not sync device <xsl:value-of select="mx:PERSONID"/>: they are not marked as Synchronize with AlarmPoint within Tivoli SRM.</suppressionMessage>
  </xsl:template>

  <!-- Include all objects by default if a personAction is not set -->
  <xsl:template match="//mx:PERSON" priority="0">
    <xsl:apply-templates select="../mx:PERSON" mode="apply-sync-rules" />
  </xsl:template>

  <!-- Include ONLY those objects which are on the personList -->
  <xsl:template match="//mx:PERSON[$personAction = 'INCLUDE']" priority="1" mode="apply-sync-rules">
    <xsl:choose>
      <xsl:when test="xalan:nodeset($personList)/person/mx:PERSONID[text() = $id]">
        <xsl:apply-templates select="../mx:PERSON" mode="process" />
      </xsl:when>
      <xsl:otherwise>
        <suppressionMessage>Do not sync device <xsl:value-of select="mx:PERSONID"/>: the personAction is set to INCLUDE, but the PERSONID is not in the specified personList.</suppressionMessage>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Exclude those objects which are on the personList -->
  <xsl:template match="//mx:PERSON[$personAction = 'EXCLUDE']" priority="1" mode="apply-sync-rules">
    <xsl:choose>
      <xsl:when test="xalan:nodeset($personList)/person/mx:PERSONID[text() = $id]">
        <suppressionMessage>Do not sync device <xsl:value-of select="mx:PERSONID"/>: the personAction is set to EXCLUDE and the PERSONID is in the personList to be excluded.</suppressionMessage>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="../mx:PERSON" mode="process" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Include all objects by default if a personAction is not set -->
  <xsl:template match="//mx:PERSON" priority="0" mode="apply-sync-rules">
    <xsl:apply-templates select="../mx:PERSON" mode="process" />
  </xsl:template>

  <!-- 
    Parse out the AlarmPoint SMS device information from the Maximo PERSON
   -->
  <xsl:template match="mx:PERSON" mode="process">
    <ap:device xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
      <!-- The owner attribute is required and must be the target name of the person this device is for -->
      <xsl:attribute name="owner">
        <xsl:value-of select="mx:PERSONID" />
      </xsl:attribute>
    
      <!-- Define the default behavior here -->
      <xsl:attribute name="seedOnly">false</xsl:attribute>
      <!-- Override the default behavior if necessary -->
      <xsl:if test="xalan:nodeset($seedOnlyList)/person/mx:PERSONID[text() = $id]">
        <xsl:attribute name="seedOnly">true</xsl:attribute>
      </xsl:if>
      
      <!-- Define the default behavior here -->
      <xsl:attribute name="deletable">true</xsl:attribute>
      <!-- Override the default behavior if necessary -->
      <xsl:if test="xalan:nodeset($undeletableList)/person/mx:PERSONID[text() = $id]">
        <xsl:attribute name="deletable">false</xsl:attribute>
      </xsl:if>
      
      <ap:blackberryDevice xsi:nil="true" />
      <ap:emailDevice xsi:nil="true" />
      <ap:genericDevice xsi:nil="true" />
      <ap:imDevice xsi:nil="true" />
      <ap:numericPagerDevice xsi:nil="true" />
      <ap:textPagerDevice xsi:nil="true" />
      <ap:textPhoneDevice>
      
        <ap:active>true</ap:active>
        <ap:default>true</ap:default>
        <ap:delay>0</ap:delay>
        <ap:externallyOwned>false</ap:externallyOwned>
        <ap:name>SMS Phone</ap:name>
        <ap:priorityThreshold>LOW</ap:priorityThreshold>
        <ap:userServiceProvider>
          <ap:name>Virtual Text Phone</ap:name>
        </ap:userServiceProvider>

        <xsl:choose>
          <xsl:when test="mx:SMS">
            <!-- apply templates to generate the number from the primary device -->
            <xsl:apply-templates select="mx:SMS" mode="SMS"/>
          </xsl:when>
          <xsl:otherwise>
            <ap:number />
          </xsl:otherwise>
        </xsl:choose>
      </ap:textPhoneDevice>
      <ap:voiceDevice xsi:nil="true" />
    </ap:device>
  </xsl:template>

  <!-- Process the SMS only if it is the primary number -->
  <xsl:template match="mx:SMS[child::mx:ISPRIMARY='1']" mode="SMS">
    <ap:number><xsl:value-of select="mx:ADDRESS" /></ap:number>
  </xsl:template>

  <xsl:template match="mx:SMS[child::mx:ISPRIMARY='0']" mode="SMS"/> 
</xsl:stylesheet>