<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:mx="http://www.ibm.com/maximo"
  xmlns:ap="http://www.alarmpoint.com/webservices/schema"
  xmlns:util="xalan://com.xmatters.ibm.tivoli.util.SyncUtil"
  extension-element-prefixes="util"
  xmlns:xalan="http://xml.apache.org/xalan"
  exclude-result-prefixes="xalan">
  <xsl:output method="xml" />

  <xsl:variable name="userid" select="//mx:MAXUSER/mx:PERSONID/text()"/>

  <!-- Include all objects by default if a personAction is not set -->
  <xsl:template match="//mx:MAXUSER[mx:APSYNC[text() = '1']]" priority="1">
    <xsl:apply-templates select="../mx:MAXUSER" mode="apply-sync-rules"/>
  </xsl:template>

  <!-- Include all objects by default if a personAction is not set -->
  <xsl:template match="//mx:MAXUSER[mx:APSYNC[text() = '0']]" priority="1">
    <suppressionMessage>Do not sync device <xsl:value-of select="mx:PERSONID"/>: they are not marked as Synchronize with AlarmPoint within Tivoli SRM.</suppressionMessage>
  </xsl:template>

  <!-- Include all objects by default if a personAction is not set -->
  <xsl:template match="//mx:MAXUSER" priority="0">
    <xsl:apply-templates select="../mx:MAXUSER" mode="apply-sync-rules" />
  </xsl:template>

  <!-- Include ONLY those objects which are on the personList -->
  <xsl:template match="//mx:MAXUSER[$personAction = 'INCLUDE']" priority="1" mode="apply-sync-rules">
    <xsl:choose>
      <xsl:when test="xalan:nodeset($personList)/person/mx:PERSONID[text() = $userid]">
        <xsl:apply-templates select="../mx:MAXUSER" mode="process" />
      </xsl:when>
      <xsl:otherwise>
        <suppressionMessage>Do not sync device <xsl:value-of select="mx:PERSONID"/>: the personAction is set to INCLUDE, but the PERSONID is not in the specified personList.</suppressionMessage>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Exclude those objects which are on the personList -->
  <xsl:template match="//mx:MAXUSER[$personAction = 'EXCLUDE']" priority="1" mode="apply-sync-rules">
    <xsl:choose>
      <xsl:when test="xalan:nodeset($personList)/person/mx:PERSONID[text() = $userid]">
        <suppressionMessage>Do not sync device <xsl:value-of select="mx:PERSONID"/>: the personAction is set to EXCLUDE and the PERSONID is in the personList to be excluded.</suppressionMessage>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="../mx:MAXUSER" mode="process" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Include all objects by default if a personAction is not set -->
  <xsl:template match="//mx:MAXUSER" priority="0" mode="apply-sync-rules">
    <xsl:apply-templates select="../mx:MAXUSER" mode="process" />
  </xsl:template>

  <!-- 
    Parse out the AlarmPoint phone device information from the Maximo PERSON
   -->
  <xsl:template match="mx:MAXUSER" mode="process">
    <ap:device xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
      <!-- The owner attribute is required and must be the target name of the person this device is for -->
      <xsl:attribute name="owner">
        <xsl:value-of select="mx:PERSONID" />
      </xsl:attribute>
    
      <!-- Define the default behavior here -->
      <xsl:attribute name="seedOnly">false</xsl:attribute>
      <!-- Override the default behavior if necessary -->
      <xsl:if test="xalan:nodeset($seedOnlyList)/person/mx:PERSONID[text() = $userid]">
        <xsl:attribute name="seedOnly">true</xsl:attribute>
      </xsl:if>
      
      <!-- Define the default behavior here -->
      <xsl:attribute name="deletable">true</xsl:attribute>
      <!-- Override the default behavior if necessary -->
      <xsl:if test="xalan:nodeset($undeletableList)/person/mx:PERSONID[text() = $userid]">
        <xsl:attribute name="deletable">false</xsl:attribute>
      </xsl:if>
      
      <ap:blackberryDevice xsi:nil="true" />
      <ap:emailDevice xsi:nil="true" />
      <ap:genericDevice xsi:nil="true" />
      <ap:imDevice xsi:nil="true" />
      <ap:numericPagerDevice xsi:nil="true" />
      <ap:textPagerDevice xsi:nil="true" />
      <ap:textPhoneDevice xsi:nil="true" />
      <ap:voiceDevice>
        <ap:active>true</ap:active>
        <ap:default>true</ap:default>
        <ap:delay>0</ap:delay>
        <ap:externallyOwned>false</ap:externallyOwned>
        <ap:name>Work Phone</ap:name>
        <ap:priorityThreshold>LOW</ap:priorityThreshold>
        <ap:userServiceProvider>
          <ap:name>Phone Engine</ap:name>
        </ap:userServiceProvider>
        <ap:areaCode><xsl:value-of select="mx:AREA_CODE" /></ap:areaCode>
        <ap:countryCodeOverride></ap:countryCodeOverride>
        <ap:extension><xsl:value-of select="mx:EXTENSION" /></ap:extension>
        <ap:number><xsl:value-of select="mx:PHONE_NUMBER" /></ap:number>
<!--
        <xsl:choose>
          <xsl:when test="mx:PHONE">
            <xsl:apply-templates select="mx:PHONE" mode="phone-number" />
          </xsl:when>
          <xsl:otherwise>
            <ap:number />
          </xsl:otherwise>
        </xsl:choose>
-->        
      </ap:voiceDevice>
    </ap:device>
  </xsl:template>

  <!-- Process the Phone only if it is the primary phone number -->
  <xsl:template match="mx:PHONE[child::mx:ISPRIMARY='1']" mode="phone-number">
    <xsl:variable name="number" select="string(mx:PHONENUM)"/>
    <ap:areaCode><xsl:value-of select="util:regex($number, '\D*(\d{0,3})\D*\s*([0-9]{1}[0-9., -]+)\D*$', 1)" /></ap:areaCode>
    <ap:countryCodeOverride></ap:countryCodeOverride>
    <ap:extension><xsl:value-of select="util:regex($number, '\d+')" /></ap:extension>
    <ap:number><xsl:value-of select="util:regex($number, '\D*(\d{0,3})\D*\s*([0-9]{1}[0-9., -]+)\D*$', 2)" /></ap:number>
  </xsl:template>

  <xsl:template match="mx:PHONE[child::mx:ISPRIMARY='0']" mode="phone-number"/> 

</xsl:stylesheet>